@@ -185,14 +185,14 @@
   addresses )
 
 (defun vm-ignored-reply-to (reply-to)
-  (if reply-to
+  (if (and reply-to (not (string= reply-to "")))
       (let (re-list result)
 	(setq re-list vm-reply-ignored-reply-tos)
 	(while re-list
 	  (if (string-match (car re-list) reply-to)
 	      (setq result t re-list nil)
 	    (setq re-list (cdr re-list))))
-	result )))
+	result)))
 
 ;;;###autoload
 (defun vm-mail-yank-default (&optional message)
@@ -446,7 +446,9 @@ vm-included-text-prefix is prepended to every yanked line."
 ;;;###autoload
 (defun vm-mail-send-and-exit (&rest ignored)
   "Send message and maybe delete the composition buffer.
-The value of `vm-keep-sent-mesages' determines whether the composition buffer is deleted.  If the composition is a reply to a message ina currenttly visited folder, that message is marked as having been rpelied to."
+The value of `vm-keep-sent-mesages' determines whether the composition buffer
+is deleted.  If the composition is a reply to a message in a currently visited
+folder, that message is marked as having been replied to."  
   (interactive "P")
   (vm-check-for-killed-folder)
   (if (and (boundp 'mail-alias-file)
